@@ -18,6 +18,7 @@ var namespaceuhd =
       [ "from_str", "namespaceuhd_1_1cast.html#a5b857ba26e9d461d877319aaf48ba5e3", null ],
       [ "from_str", "namespaceuhd_1_1cast.html#aff4429a8c2a2dc19cd761ca615efb109", null ],
       [ "from_str", "namespaceuhd_1_1cast.html#a9172f8c6fb15ba2bc991daf2f07399e8", null ],
+      [ "from_str", "namespaceuhd_1_1cast.html#ab55a4a7695c58698f4086190c0d7c568", null ],
       [ "from_str", "namespaceuhd_1_1cast.html#a01ae52e3bbfb7d55e5ebaff8c6c621bb", null ],
       [ "fromstr_cast", "namespaceuhd_1_1cast.html#a3505f7c302ba8fbf759c28d888cee8f3", null ],
       [ "hexstr_cast", "namespaceuhd_1_1cast.html#aa2744fe5ab41766361099fa0c9de22ce", null ],
@@ -52,6 +53,9 @@ var namespaceuhd =
     [ "analog_filter_lp", "classuhd_1_1analog__filter__lp.html", "classuhd_1_1analog__filter__lp" ],
     [ "assertion_error", "structuhd_1_1assertion__error.html", "structuhd_1_1assertion__error" ],
     [ "async_metadata_t", "structuhd_1_1async__metadata__t.html", "structuhd_1_1async__metadata__t" ],
+    [ "compat_num", "classuhd_1_1compat__num.html", "classuhd_1_1compat__num" ],
+    [ "compat_num16", "classuhd_1_1compat__num16.html", "classuhd_1_1compat__num16" ],
+    [ "compat_num32", "classuhd_1_1compat__num32.html", "classuhd_1_1compat__num32" ],
     [ "device", "classuhd_1_1device.html", "classuhd_1_1device" ],
     [ "device_addr_t", "classuhd_1_1device__addr__t.html", "classuhd_1_1device__addr__t" ],
     [ "dict", "classuhd_1_1dict.html", "classuhd_1_1dict" ],
@@ -64,7 +68,6 @@ var namespaceuhd =
     [ "fs_path", "structuhd_1_1fs__path.html", "structuhd_1_1fs__path" ],
     [ "gain_fcns_t", "structuhd_1_1gain__fcns__t.html", "structuhd_1_1gain__fcns__t" ],
     [ "gain_group", "classuhd_1_1gain__group.html", "classuhd_1_1gain__group" ],
-    [ "gps_ctrl", "classuhd_1_1gps__ctrl.html", "classuhd_1_1gps__ctrl" ],
     [ "i2c_iface", "classuhd_1_1i2c__iface.html", "classuhd_1_1i2c__iface" ],
     [ "image_loader", "classuhd_1_1image__loader.html", "classuhd_1_1image__loader" ],
     [ "index_error", "structuhd_1_1index__error.html", "structuhd_1_1index__error" ],
@@ -156,6 +159,8 @@ var namespaceuhd =
       [ "INPUT", "namespaceuhd.html#a975277bd04bee5260374db1afc10e582aa84cc046d48610b05c21fd3670d0c829", null ],
       [ "OFF", "namespaceuhd.html#a975277bd04bee5260374db1afc10e582a88559a0cfd8250c9d65970cc145c92d4", null ]
     ] ],
+    [ "assert_fpga_compat", "namespaceuhd.html#a175992e0a0505a09269fa407651383fe", null ],
+    [ "assert_fpga_compat", "namespaceuhd.html#ad653d5a22f37fe302496d5bcb39f4c0f", null ],
     [ "assert_has", "namespaceuhd.html#a6ea1a6336a5ee0168e30a76af6a807e1", null ],
     [ "assert_has", "namespaceuhd.html#ad3156c934fc71d1738ff9aea64b853fd", null ],
     [ "byte_copy", "namespaceuhd.html#a766e43a9f5c7e7e1978371bb158524d8", null ],
